unit FontDlg;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, IniFiles;

type
  TfmDlgFont = class(TForm)
    cbFonts: TComboBox;
    cbSizes: TComboBox;
    GroupBox1: TGroupBox;
    lbExample: TLabel;
    chbColor: TCheckBox;
    btnOK: TButton;
    btnCancel: TButton;
    btnColor: TButton;
    dlgColor: TColorDialog;
    procedure FormCreate(Sender: TObject);
    procedure chbColorClick(Sender: TObject);
    procedure btnColorClick(Sender: TObject);
    procedure btnOKClick(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
  private
    { Private declarations }
    CurColor: TColor;
    OKbtn: Boolean;
    function GetFontSize: Byte;
    function GetlbFontSize: Byte;
  public
    { Public declarations }
    SelFont: TFont;
    FontColSel: Boolean;
    procedure FontChange(Sender: TObject);
    function Execute: Boolean;
  end;

var
  fmDlgFont: TfmDlgFont;

implementation

uses HTMLedit;

{$R *.DFM}

procedure TfmDlgFont.FontChange(Sender: TObject);
begin
 With lbExample do
  begin
   Caption:=cbFonts.Text;
   Font.Name:=cbFonts.Text;
   Font.Size:=GetlbFontSize;
   Font.Color:=CurColor;
   Left:=GroupBox1.Width div 2-Width div 2;
   Top:=GroupBox1.Height div 2 - Height div 2;
  end;
end;

procedure TfmDlgFont.FormCreate(Sender: TObject);
const
 Sizes: array [1..7] of Byte = (8, 10, 12, 14, 18, 24, 36);
var
 i: Byte;
begin
 lbExample.Left:=GroupBox1.Width div 2 - lbExample.Width div 2;
 lbExample.Top:=GroupBox1.Height div 2 - lbExample.Height div 2;
 SelFont:=TFont.Create;
 cbFonts.Items:=Screen.Fonts;
 cbFonts.Text:='Times New Roman';
 For i:=1 to 7 do
  cbSizes.Items.Add(IntToStr(i)+' ('+IntToStr(Sizes[i])+' )');
 cbSizes.Text:='3 (12 )';
 With lbExample.Font do
  begin
   Name:=cbFonts.Text;
   Size:=GetlbFontSize;
  end;
 cbFonts.OnChange:=FontChange;
 cbSizes.OnChange:=FontChange;
end;

function TfmDlgFont.GetFontSize: Byte;
var
 i: Byte;
begin
 i:=1;
 While cbSizes.Text[i] <> ' ' do
  inc(i);
 GetFontSize:=StrToInt(Copy(cbSizes.Text,1,i-1));
end;

procedure TfmDlgFont.chbColorClick(Sender: TObject);
begin
 btnColor.Enabled:=chbColor.Checked;
end;

procedure TfmDlgFont.btnColorClick(Sender: TObject);
begin
 If dlgColor.Execute then
  begin
   CurColor:=dlgColor.Color;
   FontChange(Self);
  end;
end;

function TfmDlgFont.Execute: Boolean;
var
 Ini: TIniFile;
begin
 ShowModal;
 Execute:=False;
 If OKbtn then
  begin
   Execute:=True;
   SelFont.Name:=cbFonts.Text;
   SelFont.Size:=GetFontSize;
   SelFont.Color:=CurColor;
   FontColSel:=chbColor.Checked;
   Ini:=TIniFile.Create(IniFileName);
   Ini.WriteString('Font','Name',Font.Name);
   Ini.WriteInteger('Font','Size',Font.Size);
   Ini.Free;
  end;
end;

procedure TfmDlgFont.btnOKClick(Sender: TObject);
begin
 OKbtn:=True;
end;

procedure TfmDlgFont.FormDestroy(Sender: TObject);
begin
 SelFont.Free;
end;

function TfmDlgFont.GetlbFontSize: Byte;
var
 i, j: Integer;
begin
 i:=Length(cbSizes.Text);
 While cbSizes.Text[i] <> ' ' do
  dec(i);
 j:=i;
 While cbSizes.Text[i] <> '(' do
  dec(i);
 GetlbFontSize:=StrToInt(Copy(cbSizes.Text,i+1,j-i-1)); 
end;

end.
